Module codes

Module codes 

Code lists generated from refers/ genericode (code points only; EUPL XML stays out of git).

task lists / python3 xtask/gen_codes.py refreshes [generated_codes].

Modules

guard
Withdrawn-code hints. Not list membership.

Constants

ARTEFACT_VERSION
CEN EN 16931 validation artefacts pin. Fully-qualified tag, not the branch.
EN16931_GIT
ConnectingEurope/eInvoicing-EN16931 release tag commit. Pin: workspace docs/spec.md.
PEPPOL_BIS_VERSION
OpenPEPPOL peppol-bis-invoice-3 tag. Pin: workspace docs/spec.md.
PINT_MY_VERSION
PINT-MY Billing resources.zip version. Pin: workspace docs/spec.md.
PINT_VERSION
Peppol PINT Billing resources.zip version. Pin: workspace docs/spec.md.

Statics

RULES
Code-list membership rules (BR-CL-*).

Functions

country
true if code is a point in the generated ISO 3166-1 list.
credit_note_type
true if code is a point in the generated UNCL 1001 credit-note-type list.
currency
true if code is a point in the generated ISO 4217 list.
eas
true if code is a point in the generated EAS list.
icd
true if code is a point in the generated ISO 6523 ICD list.
invoice_type
true if code is a point in the generated UNCL 1001 invoice-type list.
mime
true if code is a point in the generated MIME subset.
pint_my_taxcat
true if code is a point in the generated PINT-MY tax-category list.
uncl_1153
true if code is a point in the generated UNCL 1153 list.
uncl_4451
true if code is a point in the generated UNCL 4451 list.
uncl_5305
true if code is a point in the generated UNCL 5305 list.
unit
true if code is a point in the generated UNECE Rec 20 list.
vatex
true if code is a point in the generated VATEX list.